model_loads is an open-source Python package for pytorch load models easy.

It's annoying to load model to gpu/cpu devices or load multi-gpus trained model to single gpu devices sometimes, And this package try to simplify it.